@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, 
- * Boston, MA 02111-1307, USA. 
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, 
+ * Boston, MA 02110-1301, USA. 
  */
 
 /*
@@ -37,7 +37,6 @@
 #include <string.h>
 
 #include <glib/gi18n.h>
-#include <mateconf/mateconf-client.h>
 
 #include <pluma/pluma-prefs-manager.h>
 
