@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, 
- * Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, 
+ * Boston, MA 02110-1301, USA.
  */
  
 /*
@@ -815,21 +815,6 @@ create_tab_label (PlumaNotebook *nb,
 	return tab_label;
 }
 
-static void
-remove_tab_label (PlumaNotebook *nb,
-		  PlumaTab      *tab)
-{
-	GtkWidget *tab_label;
-
-	tab_label = pluma_tab_label_new (tab);
-
-	g_signal_handlers_disconnect_by_func (tab_label,
-					      G_CALLBACK (close_button_clicked_cb),
-					      nb);
-
-	g_object_set_data (G_OBJECT (tab), "tab-label", NULL);
-}
-
 static GtkWidget *
 get_tab_label (PlumaTab *tab)
 {
@@ -841,6 +826,21 @@ get_tab_label (PlumaTab *tab)
 	return tab_label;
 }
 
+static void
+remove_tab_label (PlumaNotebook *nb,
+		  PlumaTab      *tab)
+{
+	GtkWidget *tab_label;
+
+	tab_label = get_tab_label (tab);
+
+	g_signal_handlers_disconnect_by_func (tab_label,
+					      G_CALLBACK (close_button_clicked_cb),
+					      nb);
+
+	g_object_set_data (G_OBJECT (tab), "tab-label", NULL);
+}
+
 /**
  * pluma_notebook_set_always_show_tabs:
  * @nb: a #PlumaNotebook
