@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, 
- * Boston, MA 02111-1307, USA. 
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, 
+ * Boston, MA 02110-1301, USA. 
  */
  
 /*
@@ -269,35 +269,41 @@ restore_button_clicked (GtkButton     *button,
 {
 	if (pluma_prefs_manager_print_font_body_can_set ())
 	{
-		const gchar *font;
+		gchar *font;
 
 		font = pluma_prefs_manager_get_default_print_font_body ();
 
 		gtk_font_button_set_font_name (
 				GTK_FONT_BUTTON (job->priv->body_fontbutton),
 				font);
+
+		g_free (font);
 	}
 	
 	if (pluma_prefs_manager_print_font_header_can_set ())
 	{
-		const gchar *font;
+		gchar *font;
 
 		font = pluma_prefs_manager_get_default_print_font_header ();
 
 		gtk_font_button_set_font_name (
 				GTK_FONT_BUTTON (job->priv->headers_fontbutton),
 				font);
+
+		g_free (font);
 	}
 
 	if (pluma_prefs_manager_print_font_numbers_can_set ())
 	{
-		const gchar *font;
+		gchar *font;
 
 		font = pluma_prefs_manager_get_default_print_font_numbers ();
 
 		gtk_font_button_set_font_name (
 				GTK_FONT_BUTTON (job->priv->numbers_fontbutton),
 				font);
+
+		g_free (font);
 	}
 }
 
