@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /*
@@ -678,7 +678,7 @@ main (int argc, char *argv[])
 	egg_set_desktop_file (DATADIR "/applications/pluma.desktop");
 #else
 	/* manually set name and icon */
-	g_set_application_name("pluma");
+	g_set_application_name("Pluma");
 	gtk_window_set_default_icon_name ("accessories-text-editor");
 #endif
 
